@@ -5,7 +5,6 @@
 #' @param w Weights. Default to NULL. 
 #' @param i Condition
 #' @param d Should detailed summary statistics be printed?
-#' @param digits Number of significant decimal digits. Default to 3
 #' @param .dots Used to work around non-standard evaluation.
 #' @examples
 #' library(dplyr)
@@ -21,33 +20,33 @@
 #' df %>% group_by(v1) %>% sum_up(starts_with("v"))
 #' @return a data.frame 
 #' @export
-sum_up <- function(x, ...,  d = FALSE, w = NULL,  i = NULL, digits = 3) {
+sum_up <- function(x, ...,  d = FALSE, w = NULL,  i = NULL) {
   UseMethod("sum_up")
 }
 
 #' @export
 #' @method sum_up default
-sum_up.default <- function(x, ...,  d = FALSE, w = NULL, digits = 3) {
+sum_up.default <- function(x, ...,  d = FALSE, w = NULL) {
   if (is.null(w)){
     x <- setNames(data_frame(x), "x")
   } else{
     x <- setNames(data_frame(x, w),  c("x", "weight"))
   }
-  sum_up_(x, .dots = "x", d = d, w = w, digits = digits)
+  sum_up_(x, .dots = "x", d = d, w = w)
 }
 
 
 
 #' @export
 #' @method sum_up data.frame
-sum_up.data.frame <- function(x, ...,  d = FALSE, w = NULL,  i = NULL, digits = 3) {
-  sum_up_(x, .dots = lazy_dots(...) , d = d, w = substitute(w), i = substitute(i), digits = digits)
+sum_up.data.frame <- function(x, ...,  d = FALSE, w = NULL,  i = NULL) {
+  sum_up_(x, .dots = lazy_dots(...) , d = d, w = substitute(w), i = substitute(i))
 }
 
 
 #' @export
 #' @rdname sum_up
-sum_up_<- function(x, ..., .dots, d = FALSE,  w= NULL,  i = NULL, digits = 3) {
+sum_up_<- function(x, ..., .dots, d = FALSE,  w= NULL,  i = NULL) {
   w <- names(select_vars_(names(x), w))
   byvars <- as.character(groups(x))
   dots <- all_dots(.dots, ..., all_named = TRUE)
@@ -70,11 +69,10 @@ sum_up_<- function(x, ..., .dots, d = FALSE,  w= NULL,  i = NULL, digits = 3) {
   }
   x <- select_(x, .dots = c(vars, byvars, w))
   # bug for do in data.table
- 
   out <- do_(x, ~describe(., d = d, wname = w, byvars = byvars))
-  out <- arrange_(out, .dots = c(byvars, "variable"))
-  out <- select_(out, .dots = c(byvars, "variable", setdiff(names(out), c("variable", byvars))))
-  print_pretty_summary(out, digits = digits)
+  out <- arrange_(out, .dots = c(byvars, "Variable"))
+  out <- select_(out, .dots = c(byvars, "Variable", setdiff(names(out), c("Variable", byvars))))
+  print_pretty_summary(out, byvars)
   invisible(out)
 }
 
@@ -111,7 +109,7 @@ describe <- function(M, d = FALSE, wname = character(0),  byvars = character(0))
     sum <- do.call(cbind, sum)
     sum <- as.data.frame(t(sum))
     sum <- bind_cols(data_frame(names), sum)
-    sum <- setNames(sum, c("variable", "N","N_NA","mean","sd","min", "max"))
+    sum <- setNames(sum, c("Variable", "Obs","Missing","Mean","StdDev","Min", "Max"))
   } else {
     N <- nrow(M)
     f=function(x){
@@ -141,21 +139,24 @@ describe <- function(M, d = FALSE, wname = character(0),  byvars = character(0))
     sum <- do.call(cbind, sum)
     sum <- as.data.frame(t(sum))
     sum <- bind_cols(data_frame(names), sum)
-    sum <- setNames(sum,  c("variable", "N","N_NA","mean","sd","skewness","kurtosis","min","p1","p5","p10","p25","p50","p75","p90","p95","p99","max"))
+    sum <- setNames(sum,  c("Variable", "Obs","Missing","Mean","StdDev","Skewness","Kurtosis","Min","p1","p5","p10","p25","p50","p75","p90","p95","p99","Max"))
   }
   sum
 }
 
 
 
-print_pretty_summary <- function(x, digits = 3){
-  if ("skewness" %in% names(x)){
-    x1 <- select_(x, ~-one_of(c("p1","p5","p10","p25","p50","p75","p90","p95","p99")))
-    x2 <-  select_(x, ~-one_of(c("N","N_NA","mean","sd","skewness","kurtosis", "min", "max")))
-   print(format(x1, digits = digits, scientific = FALSE))
-   print(format(x2, digits = digits, scientific = FALSE))
+print_pretty_summary <- function(x, byvars){
+  if ("Skewness" %in% names(x)){
+    x1 <- select_(x, ~one_of(c(byvars, "Variable", "Obs", "Missing", "Mean", "StdDev", "Skewness", "Kurtosis")))
+    x2 <- select_(x, ~one_of(c(byvars, "Variable", "Min", "p1", "p5", "p10", "p25", "p50")))
+    x3 <- select_(x, ~one_of(c(byvars, "Variable", "p50", "p75", "p90", "p95", "p99", "Max")))
+    statascii(x1, n_groups = length(byvars) + 1)
+    cat("\n")
+    statascii(x2, n_groups = length(byvars) + 1)
+    cat("\n")
+    statascii(x3, n_groups = length(byvars) + 1)
   } else{
-    print(format(x, digits = digits, scientific = FALSE))
+    statascii(x, n_groups = length(byvars) + 1)
   }
-}
-
+}
\ No newline at end of file
